@@ -581,7 +581,7 @@ gdm_text_message_dialog (const char *msg)
     if ( ! gdm_get_value_bool (GDM_KEY_CONSOLE_NOTIFY))
 		return FALSE;
 
-	if (g_access (EXPANDED_LIBEXECDIR "/gdmopen", X_OK) != 0)
+	if (g_access (LIBEXECDIR "/gdmopen", X_OK) != 0)
 		return FALSE;
 
 	if (msg[0] == '-') {
@@ -606,7 +606,7 @@ gdm_text_message_dialog (const char *msg)
 			g_setenv ("UNSAFE_TO_TRANSLATE", "yes", TRUE);
 		}
 		
-		argv[0] = EXPANDED_LIBEXECDIR "/gdmopen";
+		argv[0] = LIBEXECDIR "/gdmopen";
 		argv[1] = "-l";
 		argv[2] = "/bin/sh";
 		argv[3] = "-c";
@@ -628,7 +628,7 @@ gdm_text_message_dialog (const char *msg)
 	} else {
 		char *argv[6];
 
-		argv[0] = EXPANDED_LIBEXECDIR "/gdmopen";
+		argv[0] = LIBEXECDIR "/gdmopen";
 		argv[1] = "-l";
 		argv[2] = "/bin/sh";
 		argv[3] = "-c";
@@ -659,7 +659,7 @@ gdm_text_yesno_dialog (const char *msg, gboolean *ret)
     if ( ! gdm_get_value_bool (GDM_KEY_CONSOLE_NOTIFY))
 		return FALSE;
 	
-	if (g_access (EXPANDED_LIBEXECDIR "/gdmopen", X_OK) != 0)
+	if (g_access (LIBEXECDIR "/gdmopen", X_OK) != 0)
 		return FALSE;
 
 	if (ret != NULL)
@@ -688,7 +688,7 @@ gdm_text_yesno_dialog (const char *msg, gboolean *ret)
 			g_setenv ("UNSAFE_TO_TRANSLATE", "yes", TRUE);
 		}
 
-		argv[0] = EXPANDED_LIBEXECDIR "/gdmopen";
+		argv[0] = LIBEXECDIR "/gdmopen";
 		argv[1] = "-l";
 		argv[2] = "/bin/sh";
 		argv[3] = "-c";
@@ -732,7 +732,7 @@ gdm_text_yesno_dialog (const char *msg, gboolean *ret)
 
 		VE_IGNORE_EINTR (close (tempfd));
 
-		argv[0] = EXPANDED_LIBEXECDIR "/gdmopen";
+		argv[0] = LIBEXECDIR "/gdmopen";
 		argv[1] = "-l";
 		argv[2] = "/bin/sh";
 		argv[3] = "-c";
